import React, { useState } from 'react';
import LoadingButton from '@mui/lab/LoadingButton';
import { TextField, Typography, Paper, Snackbar, IconButton, Alert, Box } from '@mui/material';
import './Pay.css';
import { AddOutlined, CloseOutlined, DeleteOutline } from '@mui/icons-material';

const TelepayForm = () => {
  const [error, setError] = useState(null);
  const [success, setSuccess] = useState(null);
  const [formData, setFormData] = useState({
    first_name: '',
    last_name: '',
    address: '',
    city: '',
    province: '',
    country: '',
    email: '',
    phone: '',
    description: '',
    line_items: [
      { description: '', amount: '' },
    ],
  });
  const [errorSnackbarOpen, setErrorSnackbarOpen] = React.useState(false);
  const [submitted, setSubmitted] = React.useState(false);

  const handleChange = (field, value) => {
    setFormData({
      ...formData,
      [field]: value,
    });
  };

  const handleProductChange = (index, field, value) => {
    const updatedProducts = [...formData.line_items];
    updatedProducts[index][field] = value;

    setFormData({
      ...formData,
      line_items: updatedProducts,
    });
  };

  const handleAddProduct = () => {
    setFormData({
      ...formData,
      line_items: [...formData.line_items, { description: '', amount: '' }],
    });
  };

  const handleSubmit = async (e) => {
    setSubmitted(true);
    e.preventDefault();

    try {
      const basicAuthHeader = 'Basic ' + btoa('test23:password');
      const response = await fetch('https://central-staging.ivrnet.com/api/v1/invoices/create', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
          'Authorization': basicAuthHeader,
        },
        body: JSON.stringify(formData),
      });

      if (response.ok) {
        const responseData = await response.json();
        setSuccess(responseData);
      } else {
        const errorData = await response.json();
        setError(errorData.error || 'An error occurred');
        setErrorSnackbarOpen(true);
      }
    } catch (error) {
      setError('An error occurred while making the API request');
      setErrorSnackbarOpen(true);
    } finally {
      setSubmitted(false);
    }
  };

  const handleDeleteLineItem = (index) => {
    if (formData.line_items.length <= 1) {
      setError('1 line item is needed');
      setErrorSnackbarOpen(true);
      return;
    }

    const updatedLineItems = [...formData.line_items];
    updatedLineItems.splice(index, 1);
    setFormData({
      ...formData,
      line_items: updatedLineItems,
    });
  };

  return (
    <div>
      <Snackbar
        open={errorSnackbarOpen}
        autoHideDuration={3000}
        onClose={(event, reason) => {
          if (reason !== 'clickaway') {
            setErrorSnackbarOpen(false);
          }
        }}
        message={error}
        action={
          <React.Fragment>
            <IconButton
              size='small'
              aria-label='close'
              color='inherit'
              onClick={() => setErrorSnackbarOpen(false)}
            >
              <CloseOutlined fontSize='small' />
            </IconButton>
          </React.Fragment>
        }
      >
        <Alert onClose={() => setErrorSnackbarOpen(false)} severity='error' sx={{ width: '100%' }}>
          {error}
        </Alert>
      </Snackbar>

      <form onSubmit={handleSubmit}>
        <Paper elevation={1} sx={{ padding: 3, marginBottom: 4 }}>
          <Typography variant='h5' gutterBottom>
            Payment Details
          </Typography>

          <div className='form-group row mb-4'>
            <div className='col-md-2 center-label'>
              <label htmlFor='firstName' className='form-label mt-1'>First Name</label>
            </div>
            <div className='col-md-9'>
              <TextField
                id='firstName'
                label='First Name'
                placeholder='Enter your first name'
                variant='outlined'
                fullWidth
                value={formData.first_name}
                onChange={(e) => handleChange('first_name', e.target.value)}
              />
            </div>
          </div>

          <div className='form-group row mb-4'>
            <div className='col-md-2 center-label'>
              <label htmlFor='lastName' className='form-label mt-1'>Last Name</label>
            </div>
            <div className='col-md-9'>
              <TextField
                id='lastName'
                label='Last Name'
                placeholder='Enter your last name'
                variant='outlined'
                fullWidth
                value={formData.last_name}
                onChange={(e) => handleChange('last_name', e.target.value)}
              />
            </div>
          </div>

          <div className='form-group row mb-4'>
            <div className='col-md-2 center-label'>
              <label htmlFor='address' className='form-label mt-1'>Address</label>
            </div>
            <div className='col-md-9'>
              <TextField
                id='address'
                label='Address'
                autoComplete='address'
                placeholder='Enter your address'
                variant='outlined'
                fullWidth
                value={formData.address}
                onChange={(e) => handleChange('address', e.target.value)}
              />
            </div>
          </div>

          <div className='form-group row mb-4'>
            <div className='col-md-2 center-label'>
              <label htmlFor='city' className='form-label mt-1'>City</label>
            </div>
            <div className='col-md-9'>
              <TextField
                id='city'
                label='City'
                placeholder='Enter your city'
                variant='outlined'
                fullWidth
                value={formData.city}
                onChange={(e) => handleChange('city', e.target.value)}
              />
            </div>
          </div>

          <div className='form-group row mb-4'>
            <div className='col-md-2 center-label'>
              <label htmlFor='province' className='form-label mt-1'>Province</label>
            </div>
            <div className='col-md-9'>
              <TextField
                id='province'
                label='Province'
                placeholder='Enter your province'
                variant='outlined'
                fullWidth
                value={formData.province}
                onChange={(e) => handleChange('province', e.target.value)}
              />
            </div>
          </div>

          <div className='form-group row mb-4'>
            <div className='col-md-2 center-label'>
              <label htmlFor='country' className='form-label mt-1'>Country</label>
            </div>
            <div className='col-md-9'>
              <TextField
                id='country'
                label='Country'
                placeholder='Enter your country'
                variant='outlined'
                autoComplete='country'
                fullWidth
                value={formData.country}
                onChange={(e) => handleChange('country', e.target.value)}
              />
            </div>
          </div>

          <div className='form-group row mb-4'>
            <div className='col-md-2 center-label'>
              <label htmlFor='email' className='form-label mt-1'>Email</label>
            </div>
            <div className='col-md-9'>
              <TextField
                id='email'
                label='Email'
                placeholder='Enter your email'
                variant='outlined'
                autoComplete='email'
                fullWidth
                value={formData.email}
                type='email'
                onChange={(e) => handleChange('email', e.target.value)}
              />
            </div>
          </div>

          <div className='form-group row mb-4'>
            <div className='col-md-2 center-label'>
              <label htmlFor='phone' className='form-label mt-1'>Phone</label>
            </div>
            <div className='col-md-9'>
              <TextField
                id='phone'
                label='Phone'
                placeholder='Enter your phone number'
                autoComplete='phone'
                variant='outlined'
                fullWidth
                value={formData.phone}
                onChange={(e) => handleChange('phone', e.target.value)}
              />
            </div>
          </div>

          <div className='form-group row mb-4'>
            <div className='col-md-2 center-label'>
              <label htmlFor='description' className='form-label mt-1'>Description</label>
            </div>
            <div className='col-md-9'>
              <TextField
                id='description'
                label='Description'
                placeholder='Enter description'
                variant='outlined'
                fullWidth
                value={formData.description}
                onChange={(e) => handleChange('description', e.target.value)}
                required
              />
            </div>
          </div>

        </Paper>

        <Paper elevation={1} sx={{ padding: 3, marginBottom: 4 }}>
          <Typography variant='h5' gutterBottom>
            Line Items
          </Typography>

          {formData.line_items.map((lineItem, index) => (
            <div key={index} style={{ marginBottom: '1rem' }}>
              <div style={{ display: 'flex', alignItems: 'center', gap: '10px', marginBottom: '1rem' }}>
                <TextField
                  label='Description'
                  placeholder='Description'
                  className='w-100'
                  value={lineItem.description}
                  onChange={(e) => handleProductChange(index, 'description', e.target.value)}
                  required
                />
                <TextField
                  label='Amount'
                  placeholder='Enter Price'
                  type='number'
                  className='w-100'
                  value={lineItem.amount}
                  onChange={(e) => handleProductChange(index, 'amount', e.target.value)}
                  required
                />
                <IconButton
                  variant='contained'
                  color='error'
                  onClick={() => handleDeleteLineItem(index)}
                  sx={{ marginLeft: '1rem' }}
                >
                  <DeleteOutline />
                </IconButton>
              </div>
            </div>
          ))}

          <div className='d-flex w-100 justify-content-end'>
            <IconButton
              variant='outlined'
              color='primary'
              onClick={handleAddProduct}
              sx={{ marginBottom: '1rem' }}
            >
              <AddOutlined />
            </IconButton>
          </div>
        </Paper>
        {success && (
          <Paper elevation={1} style={{ backgroundColor: 'rgb(56, 142, 60)', color: 'white' }}
                 sx={{ padding: 3, marginBottom: 4 }}>
            Access Code: {success.access_code}
          </Paper>
        )}

        <Box sx={{ '& > button': { m: 1 } }}>
          <LoadingButton loading={submitted} type='submit' variant='outlined' color='primary'>
            <span>Submit</span>
          </LoadingButton>
        </Box>
      </form>
    </div>
  );
};

export default TelepayForm;
